@@ -30,13 +30,6 @@
 	# Load Java dependencies (all jars inside the java subfolder)
 	.jpackage(name = pkgname, jars = "*")
   
-  # Java version check
-  jv <- .jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
-  if(substr(jv, 1L, 1L) == "1") {
-    jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
-    if(jvn < 1.6) stop("Java 6 or higher is needed for this package")
-  }
-  
 	# Perform general XLConnect settings - pass package description
 	XLConnectSettings(packageDescription(pkgname))
 }
